<?php

namespace FluentSupportPro\App\Services;

use FluentSupport\App\Models\Attachment;
use FluentSupport\App\Models\Conversation;
use FluentSupport\App\Models\TagPivot;
use FluentSupport\App\Models\Ticket;
use FluentSupport\App\Services\Helper;
use FluentSupport\App\Services\Tickets\TicketService;

class ProTicketService extends TicketService
{
    public function addNoteOnMerge($ticket, $mergedTicket)
    {
        do_action('fluent_support/ticket_merge', $ticket, $mergedTicket);
        $message = sprintf(__('Ticket #%s has been merged with this ticket at %s', 'fluent-support'),  $mergedTicket->id, current_time('mysql'));
        Conversation::create([
            'ticket_id'         => $ticket->id,
            'person_id'         => Helper::getCurrentAgent()->id,
            'conversation_type' => 'ticket_merge_activity',
            'content'           => $message
        ]);

        return $ticket;
    }

    public function mergeCustomerTickets($ticketIDToMerge, $currentTicketId)
    {
        $parentTicket = Ticket::findOrFail($currentTicketId);
        $ticket = Ticket::findOrFail($ticketIDToMerge);

        $conversation =  Conversation::create(
            [
                'ticket_id'  => $currentTicketId,
                'content'    => $ticket->content,
                'source'     => $ticket->source,
                'person_id'  => $parentTicket->customer_id
            ]
        );
        $conversation->created_at = $ticket->created_at;
        $conversation->save();


        Conversation::where('ticket_id', $ticketIDToMerge)->update([ 'ticket_id' => $currentTicketId ]);

        Attachment::where('ticket_id', $ticketIDToMerge)->update([ 'ticket_id' => $currentTicketId ]);

        $this->addNoteOnMerge($parentTicket, $ticket);
        $ticket->deleteTicket();

        return [
            'message' => __('Tickets has been merged', 'fluent-support')
        ];
    }

    public function syncTicketWatchers($watchers, $ticketId)
    {
        $addWatchers = []; //array of watchers to add

        // Existing watchers
        $existingWatchers = TagPivot::where('source_type', 'ticket_watcher')
            ->where('source_id', $ticketId)
            ->get(['tag_id']);

        // Remove watchers that are not in the list
        // and add watchers that are not in the existing watchers
        foreach ($existingWatchers as $watcher) {
            if (!in_array($watcher->tag_id, $watchers)) {
                TagPivot::where('source_type', 'ticket_watcher')
                    ->where('source_id', $ticketId)
                    ->where('tag_id', $watcher->tag_id)
                    ->delete();
            } else {
                $getExWatcherIds = array_column($existingWatchers->toArray(), 'tag_id');
                $addWatchers = array_diff($watchers, $getExWatcherIds);
            }
        }

        // Add watchers that are not in the existing watchers
        if ($addWatchers) {
            foreach ($addWatchers as $watcherId) {
                TagPivot::create([
                    'tag_id' => $watcherId,
                    'source_id' => $ticketId,
                    'source_type' => 'ticket_watcher'
                ]);
            }
        }

        return [
            'message' => __('Watchers has been updated', 'fluent-support')
        ];
    }
}